@@ -324,7 +324,18 @@ void *		xmlXPathPopExternal	(xmlXPathParserContextPtr ctxt);
 /*
  * Variable Lookup forwarding
  */
-typedef xmlXPathObjectPtr (*xmlXPathVariableLookupFunc)	(void *ctxt,
+/**
+ * xmlXPathVariableLookupFunc:
+ * @ctxt:  an XPath context
+ * @name:  name of the variable
+ * @ns_uri:  the namespace name hosting this variable
+ *
+ * Prototype for callbacks used to plug variable lookup in the XPath
+ * engine
+ *
+ * Returns the XPath object value or NULL if not found
+ */
+typedef xmlXPathObjectPtr (*xmlXPathVariableLookupFunc) (void *ctxt,
 					 const xmlChar *name,
 					 const xmlChar *ns_uri);
 
@@ -335,8 +346,18 @@ void	xmlXPathRegisterVariableLookup	(xmlXPathContextPtr ctxt,
 /*
  * Function Lookup forwarding
  */
-typedef xmlXPathFunction
-	(*xmlXPathFuncLookupFunc)	(void *ctxt,
+/**
+ * xmlXPathFuncLookupFunc:
+ * @ctxt:  an XPath context
+ * @name:  name of the function
+ * @ns_uri:  the namespace name hosting this function
+ *
+ * Prototype for callbacks used to plug function lookup in the XPath
+ * engine
+ *
+ * Returns the XPath function or NULL if not found
+ */
+typedef xmlXPathFunction (*xmlXPathFuncLookupFunc) (void *ctxt,
 					 const xmlChar *name,
 					 const xmlChar *ns_uri);
 
@@ -448,7 +469,7 @@ int		  valuePush			(xmlXPathParserContextPtr ctxt,
 xmlXPathObjectPtr xmlXPathNewString		(const xmlChar *val);
 xmlXPathObjectPtr xmlXPathNewCString		(const char *val);
 xmlXPathObjectPtr xmlXPathWrapString		(xmlChar *val);
-xmlXPathObjectPtr xmlXPathWrapCString		(char *val);
+xmlXPathObjectPtr xmlXPathWrapCString		(char * val);
 xmlXPathObjectPtr xmlXPathNewFloat		(double val);
 xmlXPathObjectPtr xmlXPathNewBoolean		(int val);
 xmlXPathObjectPtr xmlXPathNewNodeSet		(xmlNodePtr val);
